from django.conf.urls import url
from django.urls import reverse_lazy
from django.views.generic import TemplateView, RedirectView

from journals import views as journals_views

urlpatterns = [
    # Journals
    url(r'^$', journals_views.journals, name='journals'),
    url(r'scipost_physics', RedirectView.as_view(url=reverse_lazy('scipost:landing_page',
                                                 args=['SciPostPhys']))),
    url(r'^journals_terms_and_conditions$',
        TemplateView.as_view(template_name='journals/journals_terms_and_conditions.html'),
        name='journals_terms_and_conditions'),
    url(r'^crossmark_policy$',
        TemplateView.as_view(template_name='journals/crossmark_policy.html'),
        name='crossmark_policy'),

    # Editorial and Administrative Workflow
    url(r'^initiate_publication$',
        journals_views.initiate_publication,
        name='initiate_publication'),
    url(r'^validate_publication$',
        journals_views.validate_publication,
        name='validate_publication'),
    url(r'^mark_first_author/(?P<publication_id>[0-9]+)/(?P<contributor_id>[0-9]+)$',
        journals_views.mark_first_author,
        name='mark_first_author'),
    url(r'^mark_first_author_unregistered/(?P<publication_id>[0-9]+)/(?P<unregistered_author_id>[0-9]+)$',
        journals_views.mark_first_author_unregistered,
        name='mark_first_author_unregistered'),
    url(r'^add_author/(?P<publication_id>[0-9]+)/(?P<contributor_id>[0-9]+)$',
        journals_views.add_author,
        name='add_author'),
    url(r'^add_author/(?P<publication_id>[0-9]+)$',
        journals_views.add_author,
        name='add_author'),
    url(r'^add_unregistered_author/(?P<publication_id>[0-9]+)/(?P<unregistered_author_id>[0-9]+)$',
        journals_views.add_unregistered_author,
        name='add_unregistered_author'),
    url(r'^add_new_unreg_author/(?P<publication_id>[0-9]+)$',
        journals_views.add_new_unreg_author,
        name='add_new_unreg_author'),
    url(r'^manage_metadata/(?P<doi_label>[a-zA-Z]+.[0-9]+.[0-9]+.[0-9]{3,})$',
        journals_views.manage_metadata,
        name='manage_metadata'),
    url(r'^manage_metadata/(?P<issue_doi_label>[a-zA-Z]+.[0-9]+.[0-9]+)$',
        journals_views.manage_metadata,
        name='manage_metadata'),
    url(r'^manage_metadata/$',
        journals_views.manage_metadata,
        name='manage_metadata'),
    url(r'^create_citation_list_metadata/(?P<doi_label>[a-zA-Z]+.[0-9]+.[0-9]+.[0-9]{3,})$',
        journals_views.create_citation_list_metadata,
        name='create_citation_list_metadata'),
    url(r'^update_references/(?P<doi_label>[a-zA-Z]+.[0-9]+.[0-9]+.[0-9]{3,})$',
        journals_views.update_references, name='update_references'),
    url(r'^create_funding_info_metadata/(?P<doi_label>[a-zA-Z]+.[0-9]+.[0-9]+.[0-9]{3,})$',
        journals_views.create_funding_info_metadata,
        name='create_funding_info_metadata'),
    url(r'^add_associated_grant/(?P<doi_label>[a-zA-Z]+.[0-9]+.[0-9]+.[0-9]{3,})$',
        journals_views.add_associated_grant,
        name='add_associated_grant'),
    url(r'^add_generic_funder/(?P<doi_label>[a-zA-Z]+.[0-9]+.[0-9]+.[0-9]{3,})$',
        journals_views.add_generic_funder,
        name='add_generic_funder'),
    url(r'^create_metadata_xml/(?P<doi_label>[a-zA-Z]+.[0-9]+.[0-9]+.[0-9]{3,})$',
        journals_views.create_metadata_xml,
        name='create_metadata_xml'),
    url(r'^metadata_xml_deposit/(?P<doi_label>[a-zA-Z]+.[0-9]+.[0-9]+.[0-9]{3,})/(?P<option>[a-z]+)$',
        journals_views.metadata_xml_deposit,
        name='metadata_xml_deposit'),
    url(r'^mark_deposit_success/(?P<deposit_id>[0-9]+)/(?P<success>[0-1])$',
        journals_views.mark_deposit_success,
        name='mark_deposit_success'),
    url(r'^produce_metadata_DOAJ/(?P<doi_label>[a-zA-Z]+.[0-9]+.[0-9]+.[0-9]{3,})$',
        journals_views.produce_metadata_DOAJ,
        name='produce_metadata_DOAJ'),
    url(r'^metadata_DOAJ_deposit/(?P<doi_label>[a-zA-Z]+.[0-9]+.[0-9]+.[0-9]{3,})$',
        journals_views.metadata_DOAJ_deposit,
        name='metadata_DOAJ_deposit'),
    url(r'^mark_doaj_deposit_success/(?P<deposit_id>[0-9]+)/(?P<success>[0-1])$',
        journals_views.mark_doaj_deposit_success,
        name='mark_doaj_deposit_success'),
    url(r'^harvest_citedby_list/$',
        journals_views.harvest_citedby_list,
        name='harvest_citedby_list'),
    url(r'^harvest_citedby_links/(?P<doi_label>[a-zA-Z]+.[0-9]+.[0-9]+.[0-9]{3,})$',
        journals_views.harvest_citedby_links,
        name='harvest_citedby_links'),
    url(r'^sign_existing_report/(?P<report_id>[0-9]+)$',
        journals_views.sign_existing_report,
        name='sign_existing_report'),
    url(r'^manage_report_metadata/$',
        journals_views.manage_report_metadata,
        name='manage_report_metadata'),
    url(r'^manage_comment_metadata/$',
        journals_views.manage_comment_metadata,
        name='manage_comment_metadata'),
    url(r'^mark_report_doi_needed/(?P<report_id>[0-9]+)/(?P<needed>[0-1])$',
        journals_views.mark_report_doi_needed,
        name='mark_report_doi_needed'),
    url(r'^mark_comment_doi_needed/(?P<comment_id>[0-9]+)/(?P<needed>[0-1])$',
        journals_views.mark_comment_doi_needed,
        name='mark_comment_doi_needed'),
    url(r'^generic_metadata_xml_deposit/(?P<type_of_object>[a-z]+)/(?P<object_id>[0-9]+)$',
        journals_views.generic_metadata_xml_deposit,
        name='generic_metadata_xml_deposit'),
    url(r'^mark_generic_deposit_success/(?P<deposit_id>[0-9]+)/(?P<success>[0-1])$',
        journals_views.mark_generic_deposit_success,
        name='mark_generic_deposit_success'),
]
